@@ -42,3 +42,19 @@ class BinanceClient:
     def get_wallet_response(self):
         response = self.client.account()
         return response
+
+    def exchange_info(self, symbol: str):
+        response = self.client.exchange_info(symbol)
+        return response
+
+    def avg_price(self, symbol: str):
+        response = self.client.avg_price(symbol)
+        return response
+
+    def new_position(self, params):
+        # response = self.client.new_order(**params.dict())
+        response = self.client.new_order(**params.dict())
+        logging.info(response)
+        entity_id = response.get("orderId", "test-id")
+        logging.info(f"Order id {entity_id}")
+        return entity_id
